@@ -1,4 +1,4 @@
-# Copyright (C) 2014 - 2017  Jack O. Wasey
+# Copyright (C) 2014 - 2018  Jack O. Wasey
 #
 # This file is part of icd.
 #
@@ -87,7 +87,14 @@ icd_poa_choices <- c("yes", "no", "notYes", "notNo")
 #'              date = as.Date(c("2011-01-01", "2011-01-02", "2011-01-03",
 #'                "2011-01-04", "2011-01-04")))
 #'   pt_hccs <- icd_comorbid_hcc(pts, date_name = "date")
-
+#'
+#'   pts10 <- icd_long_data(
+#'     visit_name = c("a", "b", "c", "d", "e"),
+#'     icd_name = c("I058", NA, "T82817A", "", "I69369"),
+#'     date = as.Date(c("2011-01-01", "2011-01-02", "2011-01-03", "2011-01-03", "2011-01-03")))
+#'
+#'   icd10_comorbid(pts10, map = icd10_map_ahrq)
+#'
 #' @export
 icd_comorbid <- function(x, map, ...) {
   ver <- icd_guess_version.character(map[[1]])
@@ -148,7 +155,6 @@ icd10_comorbid <- function(x,
 #' find ICD-10 comorbidities by checking parents
 #'
 #' @examples
-#' \dontrun{
 #' up <- uranium_pathology[1:50, ]
 #' stopifnot(identical(
 #' icd:::icd10_comorbid_parent_search_orig(up, icd10_map_ahrq,
@@ -159,6 +165,7 @@ icd10_comorbid <- function(x,
 #'   short_code = FALSE, short_map = TRUE, return_df = FALSE)
 #' ))
 #'
+#' \dontrun{
 #' library(microbenchmark)
 #' microbenchmark(substr("12345", 1, 4), substring("12345", 1, 4),
 #'                stringr::str_sub("12345", 1, 4), times = 1e5)
@@ -407,151 +414,6 @@ icd10_comorbid_quan_deyo <- function(x, ..., abbrev_names = TRUE, hierarchy = TR
   apply_hier_quan_deyo(cbd, abbrev_names = abbrev_names, hierarchy = hierarchy)
 }
 
-#' @rdname icd_comorbid
-#' @export
-icd9_comorbid_hcc <- function(x,
-                              date_name = "date",
-                              visit_name = NULL,
-                              icd_name = NULL
-) {
-  assert_data_frame(x, min.cols = 3, col.names = "unique")
-  assert(check_string(visit_name), check_null(visit_name))
-  assert(check_string(icd_name), check_null(icd_name))
-  visit_name <- get_visit_name(x, visit_name)
-  icd_name <- get_icd_name(x, icd_name)
-  assert_string(date_name)
-  assert_string(visit_name)
-  assert_string(icd_name)
-
-  # Add column for year
-  x$year <- as.numeric(format(x[[date_name]], "%Y"))
-
-  # merge CCs to patient data based on ICD and year drop ICD info
-  x <- merge(x, icd::icd9_map_cc, all.x = TRUE)
-
-  # Drop missing CC and convert to numeric
-  # Not all ICDs resolve to a CC by definition
-  x <- x[!is.na(x$cc), ]
-  x$cc <- as.numeric(x$cc)
-
-  # keep id, date, and cc columns only, reorder
-  x <- x[, c(visit_name, date_name, "year", "cc")]
-
-  # Keep only unique records
-  # Multiple ICDs for a patient can resolve to same CC
-  x <- unique(x)
-
-  # Import hierarchy mappings, and duplicate the ifcc column
-  # needed for future matching
-  hierarchy <- icd::icd_map_cc_hcc
-  hierarchy$cc <- hierarchy$ifcc
-
-  # Merge hierarchy rules with patient data
-  x <- merge(x, hierarchy, all.x = TRUE)
-
-  # Create a list of dataframes that contain the CCs that will be zeroed out
-  todrop <- list()
-  for (i in 1:6) {
-    todrop[[i]] <- x[!is.na(x$ifcc), c(3, 4, 5 + i)]
-  }
-
-  # Rename all dataframes in list to same column names
-  # rbind into a single dataframe
-  todrop <- lapply(1:length(todrop), function(x) {
-    names(todrop[[x]]) <- c(visit_name, date_name, "cc")
-    return(todrop[[x]])
-  }
-  )
-  todrop <- do.call(rbind, todrop)
-
-  # Remove all NAs from CC field
-  todrop <- todrop[!is.na(todrop$cc), ]
-
-  # Set flag for all of the CCs to be dropped
-  todrop$todrop <- TRUE
-
-  # Merge drop flags with patient data
-  x <- merge(x, todrop, all.x = TRUE)
-
-  # Drop flagged patients and keep columns of interest
-  x <- x[is.na(x$todrop), ]
-  x <- x[, c(visit_name, date_name, "cc")]
-  names(x) <- c(visit_name, date_name, "hcc")
-  x
-}
-
-#' @rdname icd_comorbid
-#' @export
-icd10_comorbid_hcc <- function(x,
-                               date_name = "date",
-                               visit_name = NULL,
-                               icd_name = NULL) {
-  assert_data_frame(x, min.cols = 3, col.names = "unique")
-  assert(check_string(visit_name), check_null(visit_name))
-  assert(check_string(icd_name), check_null(icd_name))
-  visit_name <- get_visit_name(x, visit_name)
-  icd_name <- get_icd_name(x, icd_name)
-  assert_string(date_name)
-  assert_string(visit_name)
-  assert_string(icd_name)
-
-  # Add column for year
-  x$year <- as.numeric(format(x[[date_name]], "%Y"))
-
-  # merge CCs to patient data based on ICD and year drop ICD info
-  x <- merge(x, icd::icd10_map_cc, all.x = TRUE)
-
-  # Drop missing CC and convert to numeric
-  # Not all ICDs resolve to a CC by definition
-  x <- x[!is.na(x$cc), ]
-  x$cc <- as.numeric(x$cc)
-
-  # keep id, date, and cc columns only, reorder
-  x <- x[, c(visit_name, date_name, "year", "cc")]
-
-  # Keep only unique records
-  # Multiple ICDs for a patient can resolve to same CC
-  x <- unique(x)
-
-  # Import hierarchy mappings, and duplicate the ifcc column
-  # needed for future matching
-  hierarchy <- icd::icd_map_cc_hcc
-  hierarchy$cc <- icd::icd_map_cc_hcc$ifcc
-
-  # Merge hierarchy rules with patient data
-  x <- merge(x, hierarchy, all.x = TRUE)
-
-  # Create a list of dataframes that contain the CCs that will be zeroed out
-  todrop <- list()
-  for (i in 1:6) {
-    todrop[[i]] <- x[!is.na(x$ifcc), c(3, 4, 5 + i)]
-  }
-
-  # Rename all dataframes in list to same column names
-  # rbind into a single dataframe
-  todrop <- lapply(1:length(todrop), function(x) {
-    names(todrop[[x]]) <- c(visit_name, date_name, "cc")
-    return(todrop[[x]])
-  }
-  )
-  todrop <- do.call(rbind, todrop)
-
-  # Remove all NAs from CC field
-  todrop <- todrop[!is.na(todrop$cc), ]
-
-  # Set flag for all of the CCs to be dropped
-  todrop$todrop <- TRUE
-
-  # Merge drop flags with patient data
-  x <- merge(x, todrop, all.x = TRUE)
-
-  # Drop flagged patients and keep columns of interest
-  x <- x[is.na(x$todrop), ]
-  x <- x[, c(visit_name, date_name, "cc")]
-  names(x) <- c(visit_name, date_name, "hcc")
-  x
-}
-
 #' @rdname icd_comorbid
 #' @export
 icd_comorbid_ahrq <- function(x, icd_name = get_icd_name(x), ...) {
@@ -600,30 +462,6 @@ icd_comorbid_quan_deyo <- function(x, icd_name = get_icd_name(x), ...) {
     stop("could not guess the ICD version using icd_name = ", icd_name)
 }
 
-#' @details Applying CMS Hierarchical Condition Categories
-#'   \code{icd_comorbid_hcc} functions differently from the rest of the
-#'   comorbidity assignment functions. This is because CMS publishes a specific
-#'   ICD to Condition Category mapping including all child ICD codes. In
-#'   addition, while these mappings were the same for 2007-2012, after 2013
-#'   there are annual versions. In addition, there is a many:many linkage
-#'   between ICD and Condition Categories (CC). Once CCs are assigned, a series
-#'   of hierarchy rules (which can also change annually) are applied to create
-#'   HCCs.
-#' @rdname icd_comorbid
-#' @param date column representing,  the date each record took place, as in each
-#'   year there is a different ICD9/10 to CC mapping). This is only necessary
-#'   for HCC mappings.
-#' @export
-icd_comorbid_hcc <- function(x, icd_name = get_icd_name(x), ...) {
-  ver <- icd_guess_version.data.frame(x, icd_name = icd_name)
-  if (ver == "icd9")
-    icd9_comorbid_hcc(x, icd_name = icd_name, ...)
-  else if (ver == "icd10")
-    icd10_comorbid_hcc(x, icd_name = icd_name, ...)
-  else
-    stop("could not guess the ICD version using icd_name = ", icd_name)
-}
-
 #' Apply hierarchy and choose naming for each comorbidity map
 #'
 #' Re-used by ICD-9 and ICD-10 versions which have the same rules.
