@@ -1,4 +1,4 @@
-// Copyright (C) 2014 - 2017  Jack O. Wasey
+// Copyright (C) 2014 - 2018  Jack O. Wasey
 //
 // This file is part of icd.
 //
@@ -18,8 +18,8 @@
 #ifndef ATTR_H_
 #define ATTR_H_
 
-#include "local.h"
-#include <Rcpp.h>
+#include <Rcpp.h>  // for RObject - RCPP_API_CLASS unavailable if only specific parts included
+#include "icd_types.h"     // for CV
 
 void setDecimalDiag(Rcpp::RObject& x, bool value);
 void setDecimalDiag(CV& x, bool);
