@@ -1,4 +1,4 @@
-// Copyright (C) 2014 - 2017  Jack O. Wasey
+// Copyright (C) 2014 - 2018  Jack O. Wasey
 //
 // This file is part of icd.
 //
@@ -18,10 +18,6 @@
 #ifndef LOCAL_H_
 #define LOCAL_H_
 
-#include "config.h"
-#include "icd_types.h"
-#include <Rcpp.h>
-
 extern "C" {
 #include "cutil.h"
 #include <cstdlib>
