@@ -1,4 +1,4 @@
-1# Copyright (C) 2014 - 2017  Jack O. Wasey
+1# Copyright (C) 2014 - 2018  Jack O. Wasey
 #
 # This file is part of icd.
 #
@@ -76,7 +76,7 @@ test_that("icd9 comorbidities correct, logical to binary ok", {
 })
 
 test_that("ahrq icd9 map recreated", {
-  skip_slow_tests()
+
 
   # skip this test if the file is not already in data-raw
   if (is.null(icd9_fetch_ahrq_sas(offline = TRUE)))
@@ -99,7 +99,7 @@ test_that("Quan Charlson icd9 map generated = saved", {
 })
 
 test_that("Quan Elix icd9 map generated = saved", {
-  skip_slow_tests()
+
   expect_equivalent(icd9_map_quan_elix, icd9_generate_map_quan_elix(save_data = FALSE))
   expect_equivalent(
     icd_get_invalid.icd_comorbidity_map(icd9_map_quan_elix, short_code = TRUE),
@@ -107,7 +107,7 @@ test_that("Quan Elix icd9 map generated = saved", {
 })
 
 test_that("Elixhauser icd9 map generated = saved", {
-  skip_slow_tests()
+
   expect_equivalent(icd9_map_elix, icd9_generate_map_elix(save_data = FALSE))
   expect_equivalent(icd_get_invalid.icd_comorbidity_map(icd9_map_elix, short_code = TRUE), list())
 })
@@ -122,7 +122,7 @@ test_that("condense big lists of comorbidities", {
   # generated by just expanding base ranges (which is how the condense works in
   # reverse)
 
-  skip_slow_tests()
+
 
   for (defined_codes in c(TRUE, FALSE)) {
     if (defined_codes) {
@@ -154,7 +154,7 @@ test_that("icd9cm_hierarchy as saved in data can be recreated as expected", {
   # avoid encoding problems by just doing this on Linux.
   skip_on_os(c("windows", "mac", "solaris"))
 
-  skip_slow_tests()
+
   skip_flat_icd9_avail_all()
   skip_on_no_rtf("2011")
 
@@ -538,11 +538,13 @@ test_that("built-in icd9 to comorbidity mappings are all valid", {
 test_that("disordered visit ids", {
   pts <- data.frame(visit_id = c("2", "1", "2", "3", "3"),
                     icd9 = c("39891", "40110", "09322", "41514", "39891"))
-  icd9_comorbid(pts, icd9_map_ahrq, short_code = TRUE)
+  res <- icd9_comorbid(pts, icd9_map_ahrq, short_code = TRUE)
+  # not guaranteed, but this seems logical?
+  expect_equal(rownames(res), c("2", "1", "3"))
 })
 
 test_that("diff comorbid works", {
-  skip_slow_tests()
+
   expect_error(icd_diff_comorbid(bad_input, bad_input))
 
   # no warning or error for good data
